# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from Tea.model import TeaModel
from typing import Dict, List


class BatchExportConfigurationsRequest(TeaModel):
    def __init__(
        self,
        data: str = None,
        namespace_id: str = None,
    ):
        # This parameter is required.
        self.data = data
        # This parameter is required.
        self.namespace_id = namespace_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data is not None:
            result['Data'] = self.data
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            self.data = m.get('Data')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        return self


class BatchExportConfigurationsResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        file_url: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.file_url = file_url
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.file_url is not None:
            result['FileUrl'] = self.file_url
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('FileUrl') is not None:
            self.file_url = m.get('FileUrl')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class BatchExportConfigurationsResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: BatchExportConfigurationsResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = BatchExportConfigurationsResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class BatchImportConfigurationsRequest(TeaModel):
    def __init__(
        self,
        file_url: str = None,
        namespace_id: str = None,
        policy: str = None,
    ):
        # This parameter is required.
        self.file_url = file_url
        # This parameter is required.
        self.namespace_id = namespace_id
        # This parameter is required.
        self.policy = policy

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.file_url is not None:
            result['FileUrl'] = self.file_url
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.policy is not None:
            result['Policy'] = self.policy
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FileUrl') is not None:
            self.file_url = m.get('FileUrl')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('Policy') is not None:
            self.policy = m.get('Policy')
        return self


class BatchImportConfigurationsResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class BatchImportConfigurationsResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: BatchImportConfigurationsResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = BatchImportConfigurationsResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class CheckConfigurationCloneRequest(TeaModel):
    def __init__(
        self,
        data: str = None,
        namespace_from: str = None,
        namespace_to: str = None,
        policy: str = None,
    ):
        # This parameter is required.
        self.data = data
        # This parameter is required.
        self.namespace_from = namespace_from
        # This parameter is required.
        self.namespace_to = namespace_to
        # This parameter is required.
        self.policy = policy

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data is not None:
            result['Data'] = self.data
        if self.namespace_from is not None:
            result['NamespaceFrom'] = self.namespace_from
        if self.namespace_to is not None:
            result['NamespaceTo'] = self.namespace_to
        if self.policy is not None:
            result['Policy'] = self.policy
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            self.data = m.get('Data')
        if m.get('NamespaceFrom') is not None:
            self.namespace_from = m.get('NamespaceFrom')
        if m.get('NamespaceTo') is not None:
            self.namespace_to = m.get('NamespaceTo')
        if m.get('Policy') is not None:
            self.policy = m.get('Policy')
        return self


class CheckConfigurationCloneResponseBodyResultSuccessItems(TeaModel):
    def __init__(
        self,
        data_id: str = None,
        group: str = None,
    ):
        self.data_id = data_id
        self.group = group

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.group is not None:
            result['Group'] = self.group
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        return self


class CheckConfigurationCloneResponseBodyResult(TeaModel):
    def __init__(
        self,
        success: bool = None,
        success_items: List[CheckConfigurationCloneResponseBodyResultSuccessItems] = None,
        total_count: int = None,
    ):
        self.success = success
        self.success_items = success_items
        self.total_count = total_count

    def validate(self):
        if self.success_items:
            for k in self.success_items:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.success is not None:
            result['Success'] = self.success
        result['SuccessItems'] = []
        if self.success_items is not None:
            for k in self.success_items:
                result['SuccessItems'].append(k.to_map() if k else None)
        if self.total_count is not None:
            result['TotalCount'] = self.total_count
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Success') is not None:
            self.success = m.get('Success')
        self.success_items = []
        if m.get('SuccessItems') is not None:
            for k in m.get('SuccessItems'):
                temp_model = CheckConfigurationCloneResponseBodyResultSuccessItems()
                self.success_items.append(temp_model.from_map(k))
        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')
        return self


class CheckConfigurationCloneResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
        result: CheckConfigurationCloneResponseBodyResult = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id
        self.result = result

    def validate(self):
        if self.result:
            self.result.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        if self.result is not None:
            result['Result'] = self.result.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        if m.get('Result') is not None:
            temp_model = CheckConfigurationCloneResponseBodyResult()
            self.result = temp_model.from_map(m['Result'])
        return self


class CheckConfigurationCloneResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: CheckConfigurationCloneResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = CheckConfigurationCloneResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class CheckConfigurationExportRequest(TeaModel):
    def __init__(
        self,
        data: str = None,
        namespace_id: str = None,
    ):
        # This parameter is required.
        self.data = data
        # This parameter is required.
        self.namespace_id = namespace_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data is not None:
            result['Data'] = self.data
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            self.data = m.get('Data')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        return self


class CheckConfigurationExportResponseBodyResult(TeaModel):
    def __init__(
        self,
        total_count: int = None,
    ):
        self.total_count = total_count

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.total_count is not None:
            result['TotalCount'] = self.total_count
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')
        return self


class CheckConfigurationExportResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
        result: CheckConfigurationExportResponseBodyResult = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id
        self.result = result

    def validate(self):
        if self.result:
            self.result.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        if self.result is not None:
            result['Result'] = self.result.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        if m.get('Result') is not None:
            temp_model = CheckConfigurationExportResponseBodyResult()
            self.result = temp_model.from_map(m['Result'])
        return self


class CheckConfigurationExportResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: CheckConfigurationExportResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = CheckConfigurationExportResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class CloneConfigurationRequest(TeaModel):
    def __init__(
        self,
        data: str = None,
        namespace_from: str = None,
        namespace_to: str = None,
        policy: str = None,
    ):
        # This parameter is required.
        self.data = data
        # This parameter is required.
        self.namespace_from = namespace_from
        # This parameter is required.
        self.namespace_to = namespace_to
        # This parameter is required.
        self.policy = policy

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data is not None:
            result['Data'] = self.data
        if self.namespace_from is not None:
            result['NamespaceFrom'] = self.namespace_from
        if self.namespace_to is not None:
            result['NamespaceTo'] = self.namespace_to
        if self.policy is not None:
            result['Policy'] = self.policy
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            self.data = m.get('Data')
        if m.get('NamespaceFrom') is not None:
            self.namespace_from = m.get('NamespaceFrom')
        if m.get('NamespaceTo') is not None:
            self.namespace_to = m.get('NamespaceTo')
        if m.get('Policy') is not None:
            self.policy = m.get('Policy')
        return self


class CloneConfigurationResponseBodyResultSuccessItems(TeaModel):
    def __init__(
        self,
        data_id: str = None,
        group: str = None,
    ):
        self.data_id = data_id
        self.group = group

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.group is not None:
            result['Group'] = self.group
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        return self


class CloneConfigurationResponseBodyResult(TeaModel):
    def __init__(
        self,
        success: bool = None,
        success_items: List[CloneConfigurationResponseBodyResultSuccessItems] = None,
        total_count: int = None,
    ):
        self.success = success
        self.success_items = success_items
        self.total_count = total_count

    def validate(self):
        if self.success_items:
            for k in self.success_items:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.success is not None:
            result['Success'] = self.success
        result['SuccessItems'] = []
        if self.success_items is not None:
            for k in self.success_items:
                result['SuccessItems'].append(k.to_map() if k else None)
        if self.total_count is not None:
            result['TotalCount'] = self.total_count
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Success') is not None:
            self.success = m.get('Success')
        self.success_items = []
        if m.get('SuccessItems') is not None:
            for k in m.get('SuccessItems'):
                temp_model = CloneConfigurationResponseBodyResultSuccessItems()
                self.success_items.append(temp_model.from_map(k))
        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')
        return self


class CloneConfigurationResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
        result: CloneConfigurationResponseBodyResult = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id
        self.result = result

    def validate(self):
        if self.result:
            self.result.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        if self.result is not None:
            result['Result'] = self.result.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        if m.get('Result') is not None:
            temp_model = CloneConfigurationResponseBodyResult()
            self.result = temp_model.from_map(m['Result'])
        return self


class CloneConfigurationResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: CloneConfigurationResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = CloneConfigurationResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class CreateConfigurationRequest(TeaModel):
    def __init__(
        self,
        app_name: str = None,
        content: str = None,
        data_id: str = None,
        desc: str = None,
        group: str = None,
        namespace_id: str = None,
        tags: str = None,
        type: str = None,
    ):
        self.app_name = app_name
        # This parameter is required.
        self.content = content
        # This parameter is required.
        self.data_id = data_id
        self.desc = desc
        # This parameter is required.
        self.group = group
        # This parameter is required.
        self.namespace_id = namespace_id
        self.tags = tags
        # This parameter is required.
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.app_name is not None:
            result['AppName'] = self.app_name
        if self.content is not None:
            result['Content'] = self.content
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.desc is not None:
            result['Desc'] = self.desc
        if self.group is not None:
            result['Group'] = self.group
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.tags is not None:
            result['Tags'] = self.tags
        if self.type is not None:
            result['Type'] = self.type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppName') is not None:
            self.app_name = m.get('AppName')
        if m.get('Content') is not None:
            self.content = m.get('Content')
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Desc') is not None:
            self.desc = m.get('Desc')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('Tags') is not None:
            self.tags = m.get('Tags')
        if m.get('Type') is not None:
            self.type = m.get('Type')
        return self


class CreateConfigurationResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class CreateConfigurationResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: CreateConfigurationResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = CreateConfigurationResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class CreateNamespaceRequest(TeaModel):
    def __init__(
        self,
        name: str = None,
    ):
        # This parameter is required.
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.name is not None:
            result['Name'] = self.name
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Name') is not None:
            self.name = m.get('Name')
        return self


class CreateNamespaceResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        namespace_id: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.namespace_id = namespace_id
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class CreateNamespaceResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: CreateNamespaceResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = CreateNamespaceResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DeleteConfigurationRequest(TeaModel):
    def __init__(
        self,
        data_id: str = None,
        group: str = None,
        namespace_id: str = None,
    ):
        # This parameter is required.
        self.data_id = data_id
        # This parameter is required.
        self.group = group
        # This parameter is required.
        self.namespace_id = namespace_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.group is not None:
            result['Group'] = self.group
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        return self


class DeleteConfigurationResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DeleteConfigurationResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DeleteConfigurationResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DeleteConfigurationResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DeleteNamespaceRequest(TeaModel):
    def __init__(
        self,
        namespace_id: str = None,
    ):
        # This parameter is required.
        self.namespace_id = namespace_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        return self


class DeleteNamespaceResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DeleteNamespaceResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DeleteNamespaceResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DeleteNamespaceResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DeployConfigurationRequest(TeaModel):
    def __init__(
        self,
        app_name: str = None,
        beta_ips: str = None,
        content: str = None,
        data_id: str = None,
        desc: str = None,
        group: str = None,
        namespace_id: str = None,
        tags: str = None,
        type: str = None,
    ):
        self.app_name = app_name
        self.beta_ips = beta_ips
        # This parameter is required.
        self.content = content
        # This parameter is required.
        self.data_id = data_id
        self.desc = desc
        # This parameter is required.
        self.group = group
        # This parameter is required.
        self.namespace_id = namespace_id
        self.tags = tags
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.app_name is not None:
            result['AppName'] = self.app_name
        if self.beta_ips is not None:
            result['BetaIps'] = self.beta_ips
        if self.content is not None:
            result['Content'] = self.content
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.desc is not None:
            result['Desc'] = self.desc
        if self.group is not None:
            result['Group'] = self.group
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.tags is not None:
            result['Tags'] = self.tags
        if self.type is not None:
            result['Type'] = self.type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppName') is not None:
            self.app_name = m.get('AppName')
        if m.get('BetaIps') is not None:
            self.beta_ips = m.get('BetaIps')
        if m.get('Content') is not None:
            self.content = m.get('Content')
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Desc') is not None:
            self.desc = m.get('Desc')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('Tags') is not None:
            self.tags = m.get('Tags')
        if m.get('Type') is not None:
            self.type = m.get('Type')
        return self


class DeployConfigurationResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DeployConfigurationResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DeployConfigurationResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DeployConfigurationResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DescribeConfigurationRequest(TeaModel):
    def __init__(
        self,
        data_id: str = None,
        group: str = None,
        namespace_id: str = None,
    ):
        # This parameter is required.
        self.data_id = data_id
        # This parameter is required.
        self.group = group
        # This parameter is required.
        self.namespace_id = namespace_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.group is not None:
            result['Group'] = self.group
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        return self


class DescribeConfigurationResponseBodyConfiguration(TeaModel):
    def __init__(
        self,
        app_name: str = None,
        content: str = None,
        data_id: str = None,
        desc: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        group: str = None,
        md_5: str = None,
        tags: str = None,
        type: str = None,
    ):
        self.app_name = app_name
        self.content = content
        self.data_id = data_id
        self.desc = desc
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.group = group
        self.md_5 = md_5
        self.tags = tags
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.app_name is not None:
            result['AppName'] = self.app_name
        if self.content is not None:
            result['Content'] = self.content
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.desc is not None:
            result['Desc'] = self.desc
        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create
        if self.gmt_modified is not None:
            result['GmtModified'] = self.gmt_modified
        if self.group is not None:
            result['Group'] = self.group
        if self.md_5 is not None:
            result['Md5'] = self.md_5
        if self.tags is not None:
            result['Tags'] = self.tags
        if self.type is not None:
            result['Type'] = self.type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppName') is not None:
            self.app_name = m.get('AppName')
        if m.get('Content') is not None:
            self.content = m.get('Content')
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Desc') is not None:
            self.desc = m.get('Desc')
        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')
        if m.get('GmtModified') is not None:
            self.gmt_modified = m.get('GmtModified')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('Md5') is not None:
            self.md_5 = m.get('Md5')
        if m.get('Tags') is not None:
            self.tags = m.get('Tags')
        if m.get('Type') is not None:
            self.type = m.get('Type')
        return self


class DescribeConfigurationResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        configuration: DescribeConfigurationResponseBodyConfiguration = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.configuration = configuration
        self.message = message
        self.request_id = request_id

    def validate(self):
        if self.configuration:
            self.configuration.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.configuration is not None:
            result['Configuration'] = self.configuration.to_map()
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Configuration') is not None:
            temp_model = DescribeConfigurationResponseBodyConfiguration()
            self.configuration = temp_model.from_map(m['Configuration'])
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DescribeConfigurationResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DescribeConfigurationResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DescribeConfigurationResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DescribeImportFileUrlRequest(TeaModel):
    def __init__(
        self,
        content_type: str = None,
    ):
        # This parameter is required.
        self.content_type = content_type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.content_type is not None:
            result['ContentType'] = self.content_type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ContentType') is not None:
            self.content_type = m.get('ContentType')
        return self


class DescribeImportFileUrlResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        file_url: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.file_url = file_url
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.file_url is not None:
            result['FileUrl'] = self.file_url
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('FileUrl') is not None:
            self.file_url = m.get('FileUrl')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DescribeImportFileUrlResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DescribeImportFileUrlResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DescribeImportFileUrlResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DescribeNamespaceRequest(TeaModel):
    def __init__(
        self,
        namespace_id: str = None,
    ):
        # This parameter is required.
        self.namespace_id = namespace_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        return self


class DescribeNamespaceResponseBodyNamespace(TeaModel):
    def __init__(
        self,
        access_key: str = None,
        endpoint: str = None,
        name: str = None,
        region_id: str = None,
        secret_key: str = None,
    ):
        self.access_key = access_key
        self.endpoint = endpoint
        self.name = name
        self.region_id = region_id
        self.secret_key = secret_key

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.access_key is not None:
            result['AccessKey'] = self.access_key
        if self.endpoint is not None:
            result['Endpoint'] = self.endpoint
        if self.name is not None:
            result['Name'] = self.name
        if self.region_id is not None:
            result['RegionId'] = self.region_id
        if self.secret_key is not None:
            result['SecretKey'] = self.secret_key
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccessKey') is not None:
            self.access_key = m.get('AccessKey')
        if m.get('Endpoint') is not None:
            self.endpoint = m.get('Endpoint')
        if m.get('Name') is not None:
            self.name = m.get('Name')
        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')
        if m.get('SecretKey') is not None:
            self.secret_key = m.get('SecretKey')
        return self


class DescribeNamespaceResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        namespace: DescribeNamespaceResponseBodyNamespace = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.namespace = namespace
        self.request_id = request_id

    def validate(self):
        if self.namespace:
            self.namespace.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.namespace is not None:
            result['Namespace'] = self.namespace.to_map()
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('Namespace') is not None:
            temp_model = DescribeNamespaceResponseBodyNamespace()
            self.namespace = temp_model.from_map(m['Namespace'])
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DescribeNamespaceResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DescribeNamespaceResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DescribeNamespaceResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DescribeNamespacesResponseBodyNamespaces(TeaModel):
    def __init__(
        self,
        config_count: int = None,
        namespace_id: str = None,
        namespace_name: str = None,
        quota: int = None,
        type: int = None,
    ):
        self.config_count = config_count
        self.namespace_id = namespace_id
        self.namespace_name = namespace_name
        self.quota = quota
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.config_count is not None:
            result['ConfigCount'] = self.config_count
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.namespace_name is not None:
            result['NamespaceName'] = self.namespace_name
        if self.quota is not None:
            result['Quota'] = self.quota
        if self.type is not None:
            result['Type'] = self.type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConfigCount') is not None:
            self.config_count = m.get('ConfigCount')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('NamespaceName') is not None:
            self.namespace_name = m.get('NamespaceName')
        if m.get('Quota') is not None:
            self.quota = m.get('Quota')
        if m.get('Type') is not None:
            self.type = m.get('Type')
        return self


class DescribeNamespacesResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        namespaces: List[DescribeNamespacesResponseBodyNamespaces] = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.namespaces = namespaces
        self.request_id = request_id

    def validate(self):
        if self.namespaces:
            for k in self.namespaces:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        result['Namespaces'] = []
        if self.namespaces is not None:
            for k in self.namespaces:
                result['Namespaces'].append(k.to_map() if k else None)
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        self.namespaces = []
        if m.get('Namespaces') is not None:
            for k in m.get('Namespaces'):
                temp_model = DescribeNamespacesResponseBodyNamespaces()
                self.namespaces.append(temp_model.from_map(k))
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DescribeNamespacesResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DescribeNamespacesResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DescribeNamespacesResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DescribeNamespacesWithCreateResponseBodyNamespaces(TeaModel):
    def __init__(
        self,
        config_count: int = None,
        namespace_id: str = None,
        namespace_name: str = None,
        quota: int = None,
        type: int = None,
    ):
        self.config_count = config_count
        self.namespace_id = namespace_id
        self.namespace_name = namespace_name
        self.quota = quota
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.config_count is not None:
            result['ConfigCount'] = self.config_count
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.namespace_name is not None:
            result['NamespaceName'] = self.namespace_name
        if self.quota is not None:
            result['Quota'] = self.quota
        if self.type is not None:
            result['Type'] = self.type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConfigCount') is not None:
            self.config_count = m.get('ConfigCount')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('NamespaceName') is not None:
            self.namespace_name = m.get('NamespaceName')
        if m.get('Quota') is not None:
            self.quota = m.get('Quota')
        if m.get('Type') is not None:
            self.type = m.get('Type')
        return self


class DescribeNamespacesWithCreateResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        namespaces: List[DescribeNamespacesWithCreateResponseBodyNamespaces] = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.namespaces = namespaces
        self.request_id = request_id

    def validate(self):
        if self.namespaces:
            for k in self.namespaces:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        result['Namespaces'] = []
        if self.namespaces is not None:
            for k in self.namespaces:
                result['Namespaces'].append(k.to_map() if k else None)
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        self.namespaces = []
        if m.get('Namespaces') is not None:
            for k in m.get('Namespaces'):
                temp_model = DescribeNamespacesWithCreateResponseBodyNamespaces()
                self.namespaces.append(temp_model.from_map(k))
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class DescribeNamespacesWithCreateResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DescribeNamespacesWithCreateResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DescribeNamespacesWithCreateResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class DescribeTraceByConfigurationRequest(TeaModel):
    def __init__(
        self,
        data_id: str = None,
        end_ts: str = None,
        group: str = None,
        namespace_id: str = None,
        start_ts: str = None,
    ):
        # This parameter is required.
        self.data_id = data_id
        self.end_ts = end_ts
        # This parameter is required.
        self.group = group
        # This parameter is required.
        self.namespace_id = namespace_id
        self.start_ts = start_ts

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.end_ts is not None:
            result['EndTs'] = self.end_ts
        if self.group is not None:
            result['Group'] = self.group
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.start_ts is not None:
            result['StartTs'] = self.start_ts
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('EndTs') is not None:
            self.end_ts = m.get('EndTs')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('StartTs') is not None:
            self.start_ts = m.get('StartTs')
        return self


class DescribeTraceByConfigurationResponseBodyTracesEventGroupsEventDetails(TeaModel):
    def __init__(
        self,
        data_id: str = None,
        delay: str = None,
        event: str = None,
        ext: str = None,
        group: str = None,
        handle_ip: str = None,
        log_date: str = None,
        request_ip: str = None,
        response_ip: str = None,
        ts: str = None,
        type: str = None,
    ):
        self.data_id = data_id
        self.delay = delay
        self.event = event
        self.ext = ext
        self.group = group
        self.handle_ip = handle_ip
        self.log_date = log_date
        self.request_ip = request_ip
        self.response_ip = response_ip
        self.ts = ts
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.data_id is not None:
            result['DataId'] = self.data_id
        if self.delay is not None:
            result['Delay'] = self.delay
        if self.event is not None:
            result['Event'] = self.event
        if self.ext is not None:
            result['Ext'] = self.ext
        if self.group is not None:
            result['Group'] = self.group
        if self.handle_ip is not None:
            result['HandleIp'] = self.handle_ip
        if self.log_date is not None:
            result['LogDate'] = self.log_date
        if self.request_ip is not None:
            result['RequestIp'] = self.request_ip
        if self.response_ip is not None:
            result['ResponseIp'] = self.response_ip
        if self.ts is not None:
            result['Ts'] = self.ts
        if self.type is not None:
            result['Type'] = self.type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DataId') is not None:
            self.data_id = m.get('DataId')
        if m.get('Delay') is not None:
            self.delay = m.get('Delay')
        if m.get('Event') is not None:
            self.event = m.get('Event')
        if m.get('Ext') is not None:
            self.ext = m.get('Ext')
        if m.get('Group') is not None:
            self.group = m.get('Group')
        if m.get('HandleIp') is not None:
            self.handle_ip = m.get('HandleIp')
        if m.get('LogDate') is not None:
            self.log_date = m.get('LogDate')
        if m.get('RequestIp') is not None:
            self.request_ip = m.get('RequestIp')
        if m.get('ResponseIp') is not None:
            self.response_ip = m.get('ResponseIp')
        if m.get('Ts') is not None:
            self.ts = m.get('Ts')
        if m.get('Type') is not None:
            self.type = m.get('Type')
        return self


class DescribeTraceByConfigurationResponseBodyTracesEventGroups(TeaModel):
    def __init__(
        self,
        event_details: List[DescribeTraceByConfigurationResponseBodyTracesEventGroupsEventDetails] = None,
        event_type: str = None,
    ):
        self.event_details = event_details
        self.event_type = event_type

    def validate(self):
        if self.event_details:
            for k in self.event_details:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        result['EventDetails'] = []
        if self.event_details is not None:
            for k in self.event_details:
                result['EventDetails'].append(k.to_map() if k else None)
        if self.event_type is not None:
            result['EventType'] = self.event_type
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.event_details = []
        if m.get('EventDetails') is not None:
            for k in m.get('EventDetails'):
                temp_model = DescribeTraceByConfigurationResponseBodyTracesEventGroupsEventDetails()
                self.event_details.append(temp_model.from_map(k))
        if m.get('EventType') is not None:
            self.event_type = m.get('EventType')
        return self


class DescribeTraceByConfigurationResponseBodyTraces(TeaModel):
    def __init__(
        self,
        event_groups: List[DescribeTraceByConfigurationResponseBodyTracesEventGroups] = None,
        timestamp: int = None,
    ):
        self.event_groups = event_groups
        self.timestamp = timestamp

    def validate(self):
        if self.event_groups:
            for k in self.event_groups:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        result['EventGroups'] = []
        if self.event_groups is not None:
            for k in self.event_groups:
                result['EventGroups'].append(k.to_map() if k else None)
        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.event_groups = []
        if m.get('EventGroups') is not None:
            for k in m.get('EventGroups'):
                temp_model = DescribeTraceByConfigurationResponseBodyTracesEventGroups()
                self.event_groups.append(temp_model.from_map(k))
        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')
        return self


class DescribeTraceByConfigurationResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
        traces: List[DescribeTraceByConfigurationResponseBodyTraces] = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id
        self.traces = traces

    def validate(self):
        if self.traces:
            for k in self.traces:
                if k:
                    k.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        result['Traces'] = []
        if self.traces is not None:
            for k in self.traces:
                result['Traces'].append(k.to_map() if k else None)
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        self.traces = []
        if m.get('Traces') is not None:
            for k in m.get('Traces'):
                temp_model = DescribeTraceByConfigurationResponseBodyTraces()
                self.traces.append(temp_model.from_map(k))
        return self


class DescribeTraceByConfigurationResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: DescribeTraceByConfigurationResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = DescribeTraceByConfigurationResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self


class UpdateNamespaceRequest(TeaModel):
    def __init__(
        self,
        namespace_id: str = None,
        namespace_name: str = None,
    ):
        # This parameter is required.
        self.namespace_id = namespace_id
        # This parameter is required.
        self.namespace_name = namespace_name

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id
        if self.namespace_name is not None:
            result['NamespaceName'] = self.namespace_name
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')
        if m.get('NamespaceName') is not None:
            self.namespace_name = m.get('NamespaceName')
        return self


class UpdateNamespaceResponseBody(TeaModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
        request_id: str = None,
    ):
        self.code = code
        self.message = message
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.code is not None:
            result['Code'] = self.code
        if self.message is not None:
            result['Message'] = self.message
        if self.request_id is not None:
            result['RequestId'] = self.request_id
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')
        if m.get('Message') is not None:
            self.message = m.get('Message')
        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')
        return self


class UpdateNamespaceResponse(TeaModel):
    def __init__(
        self,
        headers: Dict[str, str] = None,
        status_code: int = None,
        body: UpdateNamespaceResponseBody = None,
    ):
        self.headers = headers
        self.status_code = status_code
        self.body = body

    def validate(self):
        if self.body:
            self.body.validate()

    def to_map(self):
        _map = super().to_map()
        if _map is not None:
            return _map

        result = dict()
        if self.headers is not None:
            result['headers'] = self.headers
        if self.status_code is not None:
            result['statusCode'] = self.status_code
        if self.body is not None:
            result['body'] = self.body.to_map()
        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('headers') is not None:
            self.headers = m.get('headers')
        if m.get('statusCode') is not None:
            self.status_code = m.get('statusCode')
        if m.get('body') is not None:
            temp_model = UpdateNamespaceResponseBody()
            self.body = temp_model.from_map(m['body'])
        return self





# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from typing import Dict
from Tea.core import TeaCore

from alibabacloud_tea_openapi.client import Client as OpenApiClient
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_tea_util.client import Client as UtilClient
from alibabacloud_endpoint_util.client import Client as EndpointUtilClient
from alibabacloud_acm20200206 import models as acm_20200206_models
from alibabacloud_tea_util import models as util_models
from alibabacloud_openapi_util.client import Client as OpenApiUtilClient


class Client(OpenApiClient):
    """
    *\
    """
    def __init__(
        self, 
        config: open_api_models.Config,
    ):
        super().__init__(config)
        self._endpoint_rule = 'regional'
        self.check_config(config)
        self._endpoint = self.get_endpoint('acm', self._region_id, self._endpoint_rule, self._network, self._suffix, self._endpoint_map, self._endpoint)

    def get_endpoint(
        self,
        product_id: str,
        region_id: str,
        endpoint_rule: str,
        network: str,
        suffix: str,
        endpoint_map: Dict[str, str],
        endpoint: str,
    ) -> str:
        if not UtilClient.empty(endpoint):
            return endpoint
        if not UtilClient.is_unset(endpoint_map) and not UtilClient.empty(endpoint_map.get(region_id)):
            return endpoint_map.get(region_id)
        return EndpointUtilClient.get_endpoint_rules(product_id, region_id, endpoint_rule, network, suffix)

    def batch_export_configurations_with_options(
        self,
        request: acm_20200206_models.BatchExportConfigurationsRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.BatchExportConfigurationsResponse:
        """
        @param request: BatchExportConfigurationsRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: BatchExportConfigurationsResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data):
            query['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='BatchExportConfigurations',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/export',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.BatchExportConfigurationsResponse(),
            self.call_api(params, req, runtime)
        )

    async def batch_export_configurations_with_options_async(
        self,
        request: acm_20200206_models.BatchExportConfigurationsRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.BatchExportConfigurationsResponse:
        """
        @param request: BatchExportConfigurationsRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: BatchExportConfigurationsResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data):
            query['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='BatchExportConfigurations',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/export',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.BatchExportConfigurationsResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def batch_export_configurations(
        self,
        request: acm_20200206_models.BatchExportConfigurationsRequest,
    ) -> acm_20200206_models.BatchExportConfigurationsResponse:
        """
        @param request: BatchExportConfigurationsRequest
        @return: BatchExportConfigurationsResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.batch_export_configurations_with_options(request, headers, runtime)

    async def batch_export_configurations_async(
        self,
        request: acm_20200206_models.BatchExportConfigurationsRequest,
    ) -> acm_20200206_models.BatchExportConfigurationsResponse:
        """
        @param request: BatchExportConfigurationsRequest
        @return: BatchExportConfigurationsResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.batch_export_configurations_with_options_async(request, headers, runtime)

    def batch_import_configurations_with_options(
        self,
        request: acm_20200206_models.BatchImportConfigurationsRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.BatchImportConfigurationsResponse:
        """
        @param request: BatchImportConfigurationsRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: BatchImportConfigurationsResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.file_url):
            body['FileUrl'] = request.file_url
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.policy):
            body['Policy'] = request.policy
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='BatchImportConfigurations',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/import',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.BatchImportConfigurationsResponse(),
            self.call_api(params, req, runtime)
        )

    async def batch_import_configurations_with_options_async(
        self,
        request: acm_20200206_models.BatchImportConfigurationsRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.BatchImportConfigurationsResponse:
        """
        @param request: BatchImportConfigurationsRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: BatchImportConfigurationsResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.file_url):
            body['FileUrl'] = request.file_url
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.policy):
            body['Policy'] = request.policy
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='BatchImportConfigurations',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/import',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.BatchImportConfigurationsResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def batch_import_configurations(
        self,
        request: acm_20200206_models.BatchImportConfigurationsRequest,
    ) -> acm_20200206_models.BatchImportConfigurationsResponse:
        """
        @param request: BatchImportConfigurationsRequest
        @return: BatchImportConfigurationsResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.batch_import_configurations_with_options(request, headers, runtime)

    async def batch_import_configurations_async(
        self,
        request: acm_20200206_models.BatchImportConfigurationsRequest,
    ) -> acm_20200206_models.BatchImportConfigurationsResponse:
        """
        @param request: BatchImportConfigurationsRequest
        @return: BatchImportConfigurationsResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.batch_import_configurations_with_options_async(request, headers, runtime)

    def check_configuration_clone_with_options(
        self,
        request: acm_20200206_models.CheckConfigurationCloneRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CheckConfigurationCloneResponse:
        """
        @param request: CheckConfigurationCloneRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CheckConfigurationCloneResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.data):
            body['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_from):
            body['NamespaceFrom'] = request.namespace_from
        if not UtilClient.is_unset(request.namespace_to):
            body['NamespaceTo'] = request.namespace_to
        if not UtilClient.is_unset(request.policy):
            body['Policy'] = request.policy
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CheckConfigurationClone',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/checkForClone',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CheckConfigurationCloneResponse(),
            self.call_api(params, req, runtime)
        )

    async def check_configuration_clone_with_options_async(
        self,
        request: acm_20200206_models.CheckConfigurationCloneRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CheckConfigurationCloneResponse:
        """
        @param request: CheckConfigurationCloneRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CheckConfigurationCloneResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.data):
            body['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_from):
            body['NamespaceFrom'] = request.namespace_from
        if not UtilClient.is_unset(request.namespace_to):
            body['NamespaceTo'] = request.namespace_to
        if not UtilClient.is_unset(request.policy):
            body['Policy'] = request.policy
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CheckConfigurationClone',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/checkForClone',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CheckConfigurationCloneResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def check_configuration_clone(
        self,
        request: acm_20200206_models.CheckConfigurationCloneRequest,
    ) -> acm_20200206_models.CheckConfigurationCloneResponse:
        """
        @param request: CheckConfigurationCloneRequest
        @return: CheckConfigurationCloneResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.check_configuration_clone_with_options(request, headers, runtime)

    async def check_configuration_clone_async(
        self,
        request: acm_20200206_models.CheckConfigurationCloneRequest,
    ) -> acm_20200206_models.CheckConfigurationCloneResponse:
        """
        @param request: CheckConfigurationCloneRequest
        @return: CheckConfigurationCloneResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.check_configuration_clone_with_options_async(request, headers, runtime)

    def check_configuration_export_with_options(
        self,
        request: acm_20200206_models.CheckConfigurationExportRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CheckConfigurationExportResponse:
        """
        @param request: CheckConfigurationExportRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CheckConfigurationExportResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.data):
            body['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CheckConfigurationExport',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/checkForExport',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CheckConfigurationExportResponse(),
            self.call_api(params, req, runtime)
        )

    async def check_configuration_export_with_options_async(
        self,
        request: acm_20200206_models.CheckConfigurationExportRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CheckConfigurationExportResponse:
        """
        @param request: CheckConfigurationExportRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CheckConfigurationExportResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.data):
            body['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CheckConfigurationExport',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/checkForExport',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CheckConfigurationExportResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def check_configuration_export(
        self,
        request: acm_20200206_models.CheckConfigurationExportRequest,
    ) -> acm_20200206_models.CheckConfigurationExportResponse:
        """
        @param request: CheckConfigurationExportRequest
        @return: CheckConfigurationExportResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.check_configuration_export_with_options(request, headers, runtime)

    async def check_configuration_export_async(
        self,
        request: acm_20200206_models.CheckConfigurationExportRequest,
    ) -> acm_20200206_models.CheckConfigurationExportResponse:
        """
        @param request: CheckConfigurationExportRequest
        @return: CheckConfigurationExportResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.check_configuration_export_with_options_async(request, headers, runtime)

    def clone_configuration_with_options(
        self,
        request: acm_20200206_models.CloneConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CloneConfigurationResponse:
        """
        @param request: CloneConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CloneConfigurationResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.data):
            body['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_from):
            body['NamespaceFrom'] = request.namespace_from
        if not UtilClient.is_unset(request.namespace_to):
            body['NamespaceTo'] = request.namespace_to
        if not UtilClient.is_unset(request.policy):
            body['Policy'] = request.policy
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CloneConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/clone',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CloneConfigurationResponse(),
            self.call_api(params, req, runtime)
        )

    async def clone_configuration_with_options_async(
        self,
        request: acm_20200206_models.CloneConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CloneConfigurationResponse:
        """
        @param request: CloneConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CloneConfigurationResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.data):
            body['Data'] = request.data
        if not UtilClient.is_unset(request.namespace_from):
            body['NamespaceFrom'] = request.namespace_from
        if not UtilClient.is_unset(request.namespace_to):
            body['NamespaceTo'] = request.namespace_to
        if not UtilClient.is_unset(request.policy):
            body['Policy'] = request.policy
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CloneConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/clone',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CloneConfigurationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def clone_configuration(
        self,
        request: acm_20200206_models.CloneConfigurationRequest,
    ) -> acm_20200206_models.CloneConfigurationResponse:
        """
        @param request: CloneConfigurationRequest
        @return: CloneConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.clone_configuration_with_options(request, headers, runtime)

    async def clone_configuration_async(
        self,
        request: acm_20200206_models.CloneConfigurationRequest,
    ) -> acm_20200206_models.CloneConfigurationResponse:
        """
        @param request: CloneConfigurationRequest
        @return: CloneConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.clone_configuration_with_options_async(request, headers, runtime)

    def create_configuration_with_options(
        self,
        request: acm_20200206_models.CreateConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CreateConfigurationResponse:
        """
        @param request: CreateConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CreateConfigurationResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.app_name):
            body['AppName'] = request.app_name
        if not UtilClient.is_unset(request.content):
            body['Content'] = request.content
        if not UtilClient.is_unset(request.data_id):
            body['DataId'] = request.data_id
        if not UtilClient.is_unset(request.desc):
            body['Desc'] = request.desc
        if not UtilClient.is_unset(request.group):
            body['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.tags):
            body['Tags'] = request.tags
        if not UtilClient.is_unset(request.type):
            body['Type'] = request.type
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CreateConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CreateConfigurationResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_configuration_with_options_async(
        self,
        request: acm_20200206_models.CreateConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CreateConfigurationResponse:
        """
        @param request: CreateConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CreateConfigurationResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.app_name):
            body['AppName'] = request.app_name
        if not UtilClient.is_unset(request.content):
            body['Content'] = request.content
        if not UtilClient.is_unset(request.data_id):
            body['DataId'] = request.data_id
        if not UtilClient.is_unset(request.desc):
            body['Desc'] = request.desc
        if not UtilClient.is_unset(request.group):
            body['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.tags):
            body['Tags'] = request.tags
        if not UtilClient.is_unset(request.type):
            body['Type'] = request.type
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CreateConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CreateConfigurationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_configuration(
        self,
        request: acm_20200206_models.CreateConfigurationRequest,
    ) -> acm_20200206_models.CreateConfigurationResponse:
        """
        @param request: CreateConfigurationRequest
        @return: CreateConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.create_configuration_with_options(request, headers, runtime)

    async def create_configuration_async(
        self,
        request: acm_20200206_models.CreateConfigurationRequest,
    ) -> acm_20200206_models.CreateConfigurationResponse:
        """
        @param request: CreateConfigurationRequest
        @return: CreateConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.create_configuration_with_options_async(request, headers, runtime)

    def create_namespace_with_options(
        self,
        request: acm_20200206_models.CreateNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CreateNamespaceResponse:
        """
        @param request: CreateNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CreateNamespaceResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.name):
            body['Name'] = request.name
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CreateNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CreateNamespaceResponse(),
            self.call_api(params, req, runtime)
        )

    async def create_namespace_with_options_async(
        self,
        request: acm_20200206_models.CreateNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.CreateNamespaceResponse:
        """
        @param request: CreateNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: CreateNamespaceResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.name):
            body['Name'] = request.name
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='CreateNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='POST',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.CreateNamespaceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def create_namespace(
        self,
        request: acm_20200206_models.CreateNamespaceRequest,
    ) -> acm_20200206_models.CreateNamespaceResponse:
        """
        @param request: CreateNamespaceRequest
        @return: CreateNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.create_namespace_with_options(request, headers, runtime)

    async def create_namespace_async(
        self,
        request: acm_20200206_models.CreateNamespaceRequest,
    ) -> acm_20200206_models.CreateNamespaceResponse:
        """
        @param request: CreateNamespaceRequest
        @return: CreateNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.create_namespace_with_options_async(request, headers, runtime)

    def delete_configuration_with_options(
        self,
        request: acm_20200206_models.DeleteConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DeleteConfigurationResponse:
        """
        @param request: DeleteConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DeleteConfigurationResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data_id):
            query['DataId'] = request.data_id
        if not UtilClient.is_unset(request.group):
            query['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DeleteConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='DELETE',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DeleteConfigurationResponse(),
            self.call_api(params, req, runtime)
        )

    async def delete_configuration_with_options_async(
        self,
        request: acm_20200206_models.DeleteConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DeleteConfigurationResponse:
        """
        @param request: DeleteConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DeleteConfigurationResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data_id):
            query['DataId'] = request.data_id
        if not UtilClient.is_unset(request.group):
            query['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DeleteConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='DELETE',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DeleteConfigurationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def delete_configuration(
        self,
        request: acm_20200206_models.DeleteConfigurationRequest,
    ) -> acm_20200206_models.DeleteConfigurationResponse:
        """
        @param request: DeleteConfigurationRequest
        @return: DeleteConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.delete_configuration_with_options(request, headers, runtime)

    async def delete_configuration_async(
        self,
        request: acm_20200206_models.DeleteConfigurationRequest,
    ) -> acm_20200206_models.DeleteConfigurationResponse:
        """
        @param request: DeleteConfigurationRequest
        @return: DeleteConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.delete_configuration_with_options_async(request, headers, runtime)

    def delete_namespace_with_options(
        self,
        request: acm_20200206_models.DeleteNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DeleteNamespaceResponse:
        """
        @param request: DeleteNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DeleteNamespaceResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DeleteNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='DELETE',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DeleteNamespaceResponse(),
            self.call_api(params, req, runtime)
        )

    async def delete_namespace_with_options_async(
        self,
        request: acm_20200206_models.DeleteNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DeleteNamespaceResponse:
        """
        @param request: DeleteNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DeleteNamespaceResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DeleteNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='DELETE',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DeleteNamespaceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def delete_namespace(
        self,
        request: acm_20200206_models.DeleteNamespaceRequest,
    ) -> acm_20200206_models.DeleteNamespaceResponse:
        """
        @param request: DeleteNamespaceRequest
        @return: DeleteNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.delete_namespace_with_options(request, headers, runtime)

    async def delete_namespace_async(
        self,
        request: acm_20200206_models.DeleteNamespaceRequest,
    ) -> acm_20200206_models.DeleteNamespaceResponse:
        """
        @param request: DeleteNamespaceRequest
        @return: DeleteNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.delete_namespace_with_options_async(request, headers, runtime)

    def deploy_configuration_with_options(
        self,
        request: acm_20200206_models.DeployConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DeployConfigurationResponse:
        """
        @param request: DeployConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DeployConfigurationResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.app_name):
            body['AppName'] = request.app_name
        if not UtilClient.is_unset(request.beta_ips):
            body['BetaIps'] = request.beta_ips
        if not UtilClient.is_unset(request.content):
            body['Content'] = request.content
        if not UtilClient.is_unset(request.data_id):
            body['DataId'] = request.data_id
        if not UtilClient.is_unset(request.desc):
            body['Desc'] = request.desc
        if not UtilClient.is_unset(request.group):
            body['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.tags):
            body['Tags'] = request.tags
        if not UtilClient.is_unset(request.type):
            body['Type'] = request.type
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='DeployConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='PUT',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DeployConfigurationResponse(),
            self.call_api(params, req, runtime)
        )

    async def deploy_configuration_with_options_async(
        self,
        request: acm_20200206_models.DeployConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DeployConfigurationResponse:
        """
        @param request: DeployConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DeployConfigurationResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.app_name):
            body['AppName'] = request.app_name
        if not UtilClient.is_unset(request.beta_ips):
            body['BetaIps'] = request.beta_ips
        if not UtilClient.is_unset(request.content):
            body['Content'] = request.content
        if not UtilClient.is_unset(request.data_id):
            body['DataId'] = request.data_id
        if not UtilClient.is_unset(request.desc):
            body['Desc'] = request.desc
        if not UtilClient.is_unset(request.group):
            body['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.tags):
            body['Tags'] = request.tags
        if not UtilClient.is_unset(request.type):
            body['Type'] = request.type
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='DeployConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='PUT',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DeployConfigurationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def deploy_configuration(
        self,
        request: acm_20200206_models.DeployConfigurationRequest,
    ) -> acm_20200206_models.DeployConfigurationResponse:
        """
        @param request: DeployConfigurationRequest
        @return: DeployConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.deploy_configuration_with_options(request, headers, runtime)

    async def deploy_configuration_async(
        self,
        request: acm_20200206_models.DeployConfigurationRequest,
    ) -> acm_20200206_models.DeployConfigurationResponse:
        """
        @param request: DeployConfigurationRequest
        @return: DeployConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.deploy_configuration_with_options_async(request, headers, runtime)

    def describe_configuration_with_options(
        self,
        request: acm_20200206_models.DescribeConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeConfigurationResponse:
        """
        @param request: DescribeConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeConfigurationResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data_id):
            query['DataId'] = request.data_id
        if not UtilClient.is_unset(request.group):
            query['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeConfigurationResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_configuration_with_options_async(
        self,
        request: acm_20200206_models.DescribeConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeConfigurationResponse:
        """
        @param request: DescribeConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeConfigurationResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data_id):
            query['DataId'] = request.data_id
        if not UtilClient.is_unset(request.group):
            query['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/configuration',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeConfigurationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_configuration(
        self,
        request: acm_20200206_models.DescribeConfigurationRequest,
    ) -> acm_20200206_models.DescribeConfigurationResponse:
        """
        @param request: DescribeConfigurationRequest
        @return: DescribeConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.describe_configuration_with_options(request, headers, runtime)

    async def describe_configuration_async(
        self,
        request: acm_20200206_models.DescribeConfigurationRequest,
    ) -> acm_20200206_models.DescribeConfigurationResponse:
        """
        @param request: DescribeConfigurationRequest
        @return: DescribeConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.describe_configuration_with_options_async(request, headers, runtime)

    def describe_import_file_url_with_options(
        self,
        request: acm_20200206_models.DescribeImportFileUrlRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeImportFileUrlResponse:
        """
        @param request: DescribeImportFileUrlRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeImportFileUrlResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.content_type):
            query['ContentType'] = request.content_type
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeImportFileUrl',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/importFileUrl',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeImportFileUrlResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_import_file_url_with_options_async(
        self,
        request: acm_20200206_models.DescribeImportFileUrlRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeImportFileUrlResponse:
        """
        @param request: DescribeImportFileUrlRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeImportFileUrlResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.content_type):
            query['ContentType'] = request.content_type
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeImportFileUrl',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/batch/importFileUrl',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeImportFileUrlResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_import_file_url(
        self,
        request: acm_20200206_models.DescribeImportFileUrlRequest,
    ) -> acm_20200206_models.DescribeImportFileUrlResponse:
        """
        @param request: DescribeImportFileUrlRequest
        @return: DescribeImportFileUrlResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.describe_import_file_url_with_options(request, headers, runtime)

    async def describe_import_file_url_async(
        self,
        request: acm_20200206_models.DescribeImportFileUrlRequest,
    ) -> acm_20200206_models.DescribeImportFileUrlResponse:
        """
        @param request: DescribeImportFileUrlRequest
        @return: DescribeImportFileUrlResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.describe_import_file_url_with_options_async(request, headers, runtime)

    def describe_namespace_with_options(
        self,
        request: acm_20200206_models.DescribeNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeNamespaceResponse:
        """
        @param request: DescribeNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeNamespaceResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeNamespaceResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_namespace_with_options_async(
        self,
        request: acm_20200206_models.DescribeNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeNamespaceResponse:
        """
        @param request: DescribeNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeNamespaceResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeNamespaceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_namespace(
        self,
        request: acm_20200206_models.DescribeNamespaceRequest,
    ) -> acm_20200206_models.DescribeNamespaceResponse:
        """
        @param request: DescribeNamespaceRequest
        @return: DescribeNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.describe_namespace_with_options(request, headers, runtime)

    async def describe_namespace_async(
        self,
        request: acm_20200206_models.DescribeNamespaceRequest,
    ) -> acm_20200206_models.DescribeNamespaceResponse:
        """
        @param request: DescribeNamespaceRequest
        @return: DescribeNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.describe_namespace_with_options_async(request, headers, runtime)

    def describe_namespaces_with_options(
        self,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeNamespacesResponse:
        """
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeNamespacesResponse
        """
        req = open_api_models.OpenApiRequest(
            headers=headers
        )
        params = open_api_models.Params(
            action='DescribeNamespaces',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace/list',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeNamespacesResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_namespaces_with_options_async(
        self,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeNamespacesResponse:
        """
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeNamespacesResponse
        """
        req = open_api_models.OpenApiRequest(
            headers=headers
        )
        params = open_api_models.Params(
            action='DescribeNamespaces',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace/list',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeNamespacesResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_namespaces(self) -> acm_20200206_models.DescribeNamespacesResponse:
        """
        @return: DescribeNamespacesResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.describe_namespaces_with_options(headers, runtime)

    async def describe_namespaces_async(self) -> acm_20200206_models.DescribeNamespacesResponse:
        """
        @return: DescribeNamespacesResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.describe_namespaces_with_options_async(headers, runtime)

    def describe_namespaces_with_create_with_options(
        self,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeNamespacesWithCreateResponse:
        """
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeNamespacesWithCreateResponse
        """
        req = open_api_models.OpenApiRequest(
            headers=headers
        )
        params = open_api_models.Params(
            action='DescribeNamespacesWithCreate',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace/listWithCreate',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeNamespacesWithCreateResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_namespaces_with_create_with_options_async(
        self,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeNamespacesWithCreateResponse:
        """
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeNamespacesWithCreateResponse
        """
        req = open_api_models.OpenApiRequest(
            headers=headers
        )
        params = open_api_models.Params(
            action='DescribeNamespacesWithCreate',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace/listWithCreate',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeNamespacesWithCreateResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_namespaces_with_create(self) -> acm_20200206_models.DescribeNamespacesWithCreateResponse:
        """
        @return: DescribeNamespacesWithCreateResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.describe_namespaces_with_create_with_options(headers, runtime)

    async def describe_namespaces_with_create_async(self) -> acm_20200206_models.DescribeNamespacesWithCreateResponse:
        """
        @return: DescribeNamespacesWithCreateResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.describe_namespaces_with_create_with_options_async(headers, runtime)

    def describe_trace_by_configuration_with_options(
        self,
        request: acm_20200206_models.DescribeTraceByConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeTraceByConfigurationResponse:
        """
        @param request: DescribeTraceByConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeTraceByConfigurationResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data_id):
            query['DataId'] = request.data_id
        if not UtilClient.is_unset(request.end_ts):
            query['EndTs'] = request.end_ts
        if not UtilClient.is_unset(request.group):
            query['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.start_ts):
            query['StartTs'] = request.start_ts
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeTraceByConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/trace/getByConfiguration',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeTraceByConfigurationResponse(),
            self.call_api(params, req, runtime)
        )

    async def describe_trace_by_configuration_with_options_async(
        self,
        request: acm_20200206_models.DescribeTraceByConfigurationRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.DescribeTraceByConfigurationResponse:
        """
        @param request: DescribeTraceByConfigurationRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: DescribeTraceByConfigurationResponse
        """
        UtilClient.validate_model(request)
        query = {}
        if not UtilClient.is_unset(request.data_id):
            query['DataId'] = request.data_id
        if not UtilClient.is_unset(request.end_ts):
            query['EndTs'] = request.end_ts
        if not UtilClient.is_unset(request.group):
            query['Group'] = request.group
        if not UtilClient.is_unset(request.namespace_id):
            query['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.start_ts):
            query['StartTs'] = request.start_ts
        req = open_api_models.OpenApiRequest(
            headers=headers,
            query=OpenApiUtilClient.query(query)
        )
        params = open_api_models.Params(
            action='DescribeTraceByConfiguration',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/trace/getByConfiguration',
            method='GET',
            auth_type='AK',
            style='ROA',
            req_body_type='json',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.DescribeTraceByConfigurationResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def describe_trace_by_configuration(
        self,
        request: acm_20200206_models.DescribeTraceByConfigurationRequest,
    ) -> acm_20200206_models.DescribeTraceByConfigurationResponse:
        """
        @param request: DescribeTraceByConfigurationRequest
        @return: DescribeTraceByConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.describe_trace_by_configuration_with_options(request, headers, runtime)

    async def describe_trace_by_configuration_async(
        self,
        request: acm_20200206_models.DescribeTraceByConfigurationRequest,
    ) -> acm_20200206_models.DescribeTraceByConfigurationResponse:
        """
        @param request: DescribeTraceByConfigurationRequest
        @return: DescribeTraceByConfigurationResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.describe_trace_by_configuration_with_options_async(request, headers, runtime)

    def update_namespace_with_options(
        self,
        request: acm_20200206_models.UpdateNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.UpdateNamespaceResponse:
        """
        @param request: UpdateNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: UpdateNamespaceResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.namespace_name):
            body['NamespaceName'] = request.namespace_name
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='UpdateNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='PUT',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.UpdateNamespaceResponse(),
            self.call_api(params, req, runtime)
        )

    async def update_namespace_with_options_async(
        self,
        request: acm_20200206_models.UpdateNamespaceRequest,
        headers: Dict[str, str],
        runtime: util_models.RuntimeOptions,
    ) -> acm_20200206_models.UpdateNamespaceResponse:
        """
        @param request: UpdateNamespaceRequest
        @param headers: map
        @param runtime: runtime options for this request RuntimeOptions
        @return: UpdateNamespaceResponse
        """
        UtilClient.validate_model(request)
        body = {}
        if not UtilClient.is_unset(request.namespace_id):
            body['NamespaceId'] = request.namespace_id
        if not UtilClient.is_unset(request.namespace_name):
            body['NamespaceName'] = request.namespace_name
        req = open_api_models.OpenApiRequest(
            headers=headers,
            body=OpenApiUtilClient.parse_to_map(body)
        )
        params = open_api_models.Params(
            action='UpdateNamespace',
            version='2020-02-06',
            protocol='HTTPS',
            pathname=f'/diamond-ops/pop/namespace',
            method='PUT',
            auth_type='AK',
            style='ROA',
            req_body_type='formData',
            body_type='json'
        )
        return TeaCore.from_map(
            acm_20200206_models.UpdateNamespaceResponse(),
            await self.call_api_async(params, req, runtime)
        )

    def update_namespace(
        self,
        request: acm_20200206_models.UpdateNamespaceRequest,
    ) -> acm_20200206_models.UpdateNamespaceResponse:
        """
        @param request: UpdateNamespaceRequest
        @return: UpdateNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return self.update_namespace_with_options(request, headers, runtime)

    async def update_namespace_async(
        self,
        request: acm_20200206_models.UpdateNamespaceRequest,
    ) -> acm_20200206_models.UpdateNamespaceResponse:
        """
        @param request: UpdateNamespaceRequest
        @return: UpdateNamespaceResponse
        """
        runtime = util_models.RuntimeOptions()
        headers = {}
        return await self.update_namespace_with_options_async(request, headers, runtime)
